==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtsedHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "string replacement by regular expression"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "list of attributes"
#define FLDC "a list of attributes for which replacement is done"
#define FLDF NULL

/*-c*/
#define REGT "regular expression"
#define REGC "specify a reguar expression for character stirngs that you want to replace"

/*-v*/
#define REPT "character string for replacement"
#define REPC "character string you will replace with"

/*-z*/
#define GLBT "global replacement"
#define GLBC "replace all substrings that match a regular expression"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "For an attribute specified by -f, replace the character string that matches a regular expression specified by -c with
a character string specified by -v."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtsed -f zip_code -c '^62' -v '###' -i dat.xt -o rsl.xt\n\
xtsed -f zip_code:permutation_code -c '^62' -v '' -i dat.xt -o rsl.xt\n\
xtsed -f zip_code -c 'abc' -v '(&)' -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtcal"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/en/xtsedHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "string replacement by regular expression"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "list of attributes"
#define FLDC "a list of attributes for which replacement is done"
#define FLDF NULL

/*-c*/
#define REGT "regular expression"
#define REGC "specify a reguar expression for character stirngs that you want to replace"

/*-v*/
#define REPT "character string for replacement"
#define REPC "character string you will replace with"

/*-z*/
#define GLBT "global replacement"
#define GLBC "replace all substrings that match a regular expression"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command replaces the character string that matches a regular expression defined by -c with a character string at the -v argument. When -A is specified, the replacement will be stored as a new attribute. Replacement is applied only for the longest substring that matches a regular expression. If there is a tie, only the first occurrence is replaced. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtsed -f zip_code -c '^62' -v '###' -i dat.xt -o rsl.xt\n\
xtsed -f zip_code:permutation_code -c '^62' -v '' -i dat.xt -o rsl.xt\n\
xtsed -f zip_code -c 'abc' -v '(&)' -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtcal"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
